==> pmml-model-1.0.0-sources.jar: org/dmg/pmml/TimeSeries.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}TimeAnchor" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}TimeValue" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="usage" type="{http://www.dmg.org/PMML-4_1}TIMESERIES-USAGE" default="original" />
 *       &lt;attribute name="startTime" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" />
 *       &lt;attribute name="endTime" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" />
 *       &lt;attribute name="interpolationMethod" type="{http://www.dmg.org/PMML-4_1}INTERPOLATION-METHOD" default="none" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "timeAnchor",
    "timeValues"
})
@XmlRootElement(name = "TimeSeries")
@Schema(min = Version.PMML_4_0)
public class TimeSeries
    extends PMMLObject
    implements Equals, HashCode
{

    @XmlElement(name = "TimeAnchor")
    protected TimeAnchor timeAnchor;
    @XmlElement(name = "TimeValue")
    protected List<TimeValue> timeValues;
    @XmlAttribute(name = "usage")
    protected TimeSeriesUsageType usage;
    @XmlAttribute(name = "startTime")
    protected Double startTime;
    @XmlAttribute(name = "endTime")
    protected Double endTime;
    @XmlAttribute(name = "interpolationMethod")
    protected InterpolationMethodType interpolationMethod;

    /**
     * Gets the value of the timeAnchor property.
     * 
     * @return
     *     possible object is
     *     {@link TimeAnchor }
     *     
     */
    public TimeAnchor getTimeAnchor() {
        return timeAnchor;
    }

    /**
     * Sets the value of the timeAnchor property.
     * 
     * @param value
     *     allowed object is
     *     {@link TimeAnchor }
     *     
     */
    public void setTimeAnchor(TimeAnchor value) {
        this.timeAnchor = value;
    }

    /**
     * Gets the value of the timeValues property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeValues property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeValues().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeValue }
     * 
     * 
     */
    public List<TimeValue> getTimeValues() {
        if (timeValues == null) {
            timeValues = new ArrayList<TimeValue>();
        }
        return this.timeValues;
    }

    /**
     * Gets the value of the usage property.
     * 
     * @return
     *     possible object is
     *     {@link TimeSeriesUsageType }
     *     
     */
    public TimeSeriesUsageType getUsage() {
        if (usage == null) {
            return TimeSeriesUsageType.ORIGINAL;
        } else {
            return usage;
        }
    }

    /**
     * Sets the value of the usage property.
     * 
     * @param value
     *     allowed object is
     *     {@link TimeSeriesUsageType }
     *     
     */
    public void setUsage(TimeSeriesUsageType value) {
        this.usage = value;
    }

    /**
     * Gets the value of the startTime property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getStartTime() {
        return startTime;
    }

    /**
     * Sets the value of the startTime property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setStartTime(Double value) {
        this.startTime = value;
    }

    /**
     * Gets the value of the endTime property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getEndTime() {
        return endTime;
    }

    /**
     * Sets the value of the endTime property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setEndTime(Double value) {
        this.endTime = value;
    }

    /**
     * Gets the value of the interpolationMethod property.
     * 
     * @return
     *     possible object is
     *     {@link InterpolationMethodType }
     *     
     */
    public InterpolationMethodType getInterpolationMethod() {
        if (interpolationMethod == null) {
            return InterpolationMethodType.NONE;
        } else {
            return interpolationMethod;
        }
    }

    /**
     * Sets the value of the interpolationMethod property.
     * 
     * @param value
     *     allowed object is
     *     {@link InterpolationMethodType }
     *     
     */
    public void setInterpolationMethod(InterpolationMethodType value) {
        this.interpolationMethod = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof TimeSeries)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final TimeSeries that = ((TimeSeries) object);
        {
            TimeAnchor lhsTimeAnchor;
            lhsTimeAnchor = this.getTimeAnchor();
            TimeAnchor rhsTimeAnchor;
            rhsTimeAnchor = that.getTimeAnchor();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "timeAnchor", lhsTimeAnchor), LocatorUtils.property(thatLocator, "timeAnchor", rhsTimeAnchor), lhsTimeAnchor, rhsTimeAnchor)) {
                return false;
            }
        }
        {
            List<TimeValue> lhsTimeValues;
            lhsTimeValues = (((this.timeValues!= null)&&(!this.timeValues.isEmpty()))?this.getTimeValues():null);
            List<TimeValue> rhsTimeValues;
            rhsTimeValues = (((that.timeValues!= null)&&(!that.timeValues.isEmpty()))?that.getTimeValues():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "timeValues", lhsTimeValues), LocatorUtils.property(thatLocator, "timeValues", rhsTimeValues), lhsTimeValues, rhsTimeValues)) {
                return false;
            }
        }
        {
            TimeSeriesUsageType lhsUsage;
            lhsUsage = this.getUsage();
            TimeSeriesUsageType rhsUsage;
            rhsUsage = that.getUsage();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "usage", lhsUsage), LocatorUtils.property(thatLocator, "usage", rhsUsage), lhsUsage, rhsUsage)) {
                return false;
            }
        }
        {
            Double lhsStartTime;
            lhsStartTime = this.getStartTime();
            Double rhsStartTime;
            rhsStartTime = that.getStartTime();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "startTime", lhsStartTime), LocatorUtils.property(thatLocator, "startTime", rhsStartTime), lhsStartTime, rhsStartTime)) {
                return false;
            }
        }
        {
            Double lhsEndTime;
            lhsEndTime = this.getEndTime();
            Double rhsEndTime;
            rhsEndTime = that.getEndTime();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "endTime", lhsEndTime), LocatorUtils.property(thatLocator, "endTime", rhsEndTime), lhsEndTime, rhsEndTime)) {
                return false;
            }
        }
        {
            InterpolationMethodType lhsInterpolationMethod;
            lhsInterpolationMethod = this.getInterpolationMethod();
            InterpolationMethodType rhsInterpolationMethod;
            rhsInterpolationMethod = that.getInterpolationMethod();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "interpolationMethod", lhsInterpolationMethod), LocatorUtils.property(thatLocator, "interpolationMethod", rhsInterpolationMethod), lhsInterpolationMethod, rhsInterpolationMethod)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            TimeAnchor theTimeAnchor;
            theTimeAnchor = this.getTimeAnchor();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "timeAnchor", theTimeAnchor), currentHashCode, theTimeAnchor);
        }
        {
            List<TimeValue> theTimeValues;
            theTimeValues = (((this.timeValues!= null)&&(!this.timeValues.isEmpty()))?this.getTimeValues():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "timeValues", theTimeValues), currentHashCode, theTimeValues);
        }
        {
            TimeSeriesUsageType theUsage;
            theUsage = this.getUsage();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "usage", theUsage), currentHashCode, theUsage);
        }
        {
            Double theStartTime;
            theStartTime = this.getStartTime();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "startTime", theStartTime), currentHashCode, theStartTime);
        }
        {
            Double theEndTime;
            theEndTime = this.getEndTime();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "endTime", theEndTime), currentHashCode, theEndTime);
        }
        {
            InterpolationMethodType theInterpolationMethod;
            theInterpolationMethod = this.getInterpolationMethod();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "interpolationMethod", theInterpolationMethod), currentHashCode, theInterpolationMethod);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

}

==> pmml-model-1.0.3-sources.jar: org/dmg/pmml/TimeSeries.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}TimeAnchor" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}TimeValue" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="usage" type="{http://www.dmg.org/PMML-4_1}TIMESERIES-USAGE" default="original" />
 *       &lt;attribute name="startTime" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" />
 *       &lt;attribute name="endTime" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" />
 *       &lt;attribute name="interpolationMethod" type="{http://www.dmg.org/PMML-4_1}INTERPOLATION-METHOD" default="none" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "timeAnchor",
    "timeValues"
})
@XmlRootElement(name = "TimeSeries")
@Schema(min = Version.PMML_4_0)
public class TimeSeries
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "TimeAnchor")
    protected TimeAnchor timeAnchor;
    @XmlElement(name = "TimeValue")
    protected List<TimeValue> timeValues;
    @XmlAttribute(name = "usage")
    protected TimeSeriesUsageType usage;
    @XmlAttribute(name = "startTime")
    protected Double startTime;
    @XmlAttribute(name = "endTime")
    protected Double endTime;
    @XmlAttribute(name = "interpolationMethod")
    protected InterpolationMethodType interpolationMethod;

    /**
     * Gets the value of the timeAnchor property.
     * 
     * @return
     *     possible object is
     *     {@link TimeAnchor }
     *     
     */
    public TimeAnchor getTimeAnchor() {
        return timeAnchor;
    }

    /**
     * Sets the value of the timeAnchor property.
     * 
     * @param value
     *     allowed object is
     *     {@link TimeAnchor }
     *     
     */
    public void setTimeAnchor(TimeAnchor value) {
        this.timeAnchor = value;
    }

    /**
     * Gets the value of the timeValues property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeValues property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeValues().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeValue }
     * 
     * 
     */
    public List<TimeValue> getTimeValues() {
        if (timeValues == null) {
            timeValues = new ArrayList<TimeValue>();
        }
        return this.timeValues;
    }

    /**
     * Gets the value of the usage property.
     * 
     * @return
     *     possible object is
     *     {@link TimeSeriesUsageType }
     *     
     */
    public TimeSeriesUsageType getUsage() {
        if (usage == null) {
            return TimeSeriesUsageType.ORIGINAL;
        } else {
            return usage;
        }
    }

    /**
     * Sets the value of the usage property.
     * 
     * @param value
     *     allowed object is
     *     {@link TimeSeriesUsageType }
     *     
     */
    public void setUsage(TimeSeriesUsageType value) {
        this.usage = value;
    }

    /**
     * Gets the value of the startTime property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getStartTime() {
        return startTime;
    }

    /**
     * Sets the value of the startTime property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setStartTime(Double value) {
        this.startTime = value;
    }

    /**
     * Gets the value of the endTime property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getEndTime() {
        return endTime;
    }

    /**
     * Sets the value of the endTime property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setEndTime(Double value) {
        this.endTime = value;
    }

    /**
     * Gets the value of the interpolationMethod property.
     * 
     * @return
     *     possible object is
     *     {@link InterpolationMethodType }
     *     
     */
    public InterpolationMethodType getInterpolationMethod() {
        if (interpolationMethod == null) {
            return InterpolationMethodType.NONE;
        } else {
            return interpolationMethod;
        }
    }

    /**
     * Sets the value of the interpolationMethod property.
     * 
     * @param value
     *     allowed object is
     *     {@link InterpolationMethodType }
     *     
     */
    public void setInterpolationMethod(InterpolationMethodType value) {
        this.interpolationMethod = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof TimeSeries)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final TimeSeries that = ((TimeSeries) object);
        {
            TimeAnchor lhsTimeAnchor;
            lhsTimeAnchor = this.getTimeAnchor();
            TimeAnchor rhsTimeAnchor;
            rhsTimeAnchor = that.getTimeAnchor();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "timeAnchor", lhsTimeAnchor), LocatorUtils.property(thatLocator, "timeAnchor", rhsTimeAnchor), lhsTimeAnchor, rhsTimeAnchor)) {
                return false;
            }
        }
        {
            List<TimeValue> lhsTimeValues;
            lhsTimeValues = (((this.timeValues!= null)&&(!this.timeValues.isEmpty()))?this.getTimeValues():null);
            List<TimeValue> rhsTimeValues;
            rhsTimeValues = (((that.timeValues!= null)&&(!that.timeValues.isEmpty()))?that.getTimeValues():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "timeValues", lhsTimeValues), LocatorUtils.property(thatLocator, "timeValues", rhsTimeValues), lhsTimeValues, rhsTimeValues)) {
                return false;
            }
        }
        {
            TimeSeriesUsageType lhsUsage;
            lhsUsage = this.getUsage();
            TimeSeriesUsageType rhsUsage;
            rhsUsage = that.getUsage();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "usage", lhsUsage), LocatorUtils.property(thatLocator, "usage", rhsUsage), lhsUsage, rhsUsage)) {
                return false;
            }
        }
        {
            Double lhsStartTime;
            lhsStartTime = this.getStartTime();
            Double rhsStartTime;
            rhsStartTime = that.getStartTime();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "startTime", lhsStartTime), LocatorUtils.property(thatLocator, "startTime", rhsStartTime), lhsStartTime, rhsStartTime)) {
                return false;
            }
        }
        {
            Double lhsEndTime;
            lhsEndTime = this.getEndTime();
            Double rhsEndTime;
            rhsEndTime = that.getEndTime();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "endTime", lhsEndTime), LocatorUtils.property(thatLocator, "endTime", rhsEndTime), lhsEndTime, rhsEndTime)) {
                return false;
            }
        }
        {
            InterpolationMethodType lhsInterpolationMethod;
            lhsInterpolationMethod = this.getInterpolationMethod();
            InterpolationMethodType rhsInterpolationMethod;
            rhsInterpolationMethod = that.getInterpolationMethod();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "interpolationMethod", lhsInterpolationMethod), LocatorUtils.property(thatLocator, "interpolationMethod", rhsInterpolationMethod), lhsInterpolationMethod, rhsInterpolationMethod)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            TimeAnchor theTimeAnchor;
            theTimeAnchor = this.getTimeAnchor();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "timeAnchor", theTimeAnchor), currentHashCode, theTimeAnchor);
        }
        {
            List<TimeValue> theTimeValues;
            theTimeValues = (((this.timeValues!= null)&&(!this.timeValues.isEmpty()))?this.getTimeValues():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "timeValues", theTimeValues), currentHashCode, theTimeValues);
        }
        {
            TimeSeriesUsageType theUsage;
            theUsage = this.getUsage();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "usage", theUsage), currentHashCode, theUsage);
        }
        {
            Double theStartTime;
            theStartTime = this.getStartTime();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "startTime", theStartTime), currentHashCode, theStartTime);
        }
        {
            Double theEndTime;
            theEndTime = this.getEndTime();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "endTime", theEndTime), currentHashCode, theEndTime);
        }
        {
            InterpolationMethodType theInterpolationMethod;
            theInterpolationMethod = this.getInterpolationMethod();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "interpolationMethod", theInterpolationMethod), currentHashCode, theInterpolationMethod);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            TimeAnchor theTimeAnchor;
            theTimeAnchor = this.getTimeAnchor();
            strategy.appendField(locator, this, "timeAnchor", buffer, theTimeAnchor);
        }
        {
            List<TimeValue> theTimeValues;
            theTimeValues = (((this.timeValues!= null)&&(!this.timeValues.isEmpty()))?this.getTimeValues():null);
            strategy.appendField(locator, this, "timeValues", buffer, theTimeValues);
        }
        {
            TimeSeriesUsageType theUsage;
            theUsage = this.getUsage();
            strategy.appendField(locator, this, "usage", buffer, theUsage);
        }
        {
            Double theStartTime;
            theStartTime = this.getStartTime();
            strategy.appendField(locator, this, "startTime", buffer, theStartTime);
        }
        {
            Double theEndTime;
            theEndTime = this.getEndTime();
            strategy.appendField(locator, this, "endTime", buffer, theEndTime);
        }
        {
            InterpolationMethodType theInterpolationMethod;
            theInterpolationMethod = this.getInterpolationMethod();
            strategy.appendField(locator, this, "interpolationMethod", buffer, theInterpolationMethod);
        }
        return buffer;
    }

}
